@@ -148,9 +148,13 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
         # most likely have not been ingested into digital preservation
         # systems yet
         if "type" in result and result["type"] == "journal-article":
-            year_published = result["published"]["date-parts"][0][0]
+            year_published = (
+                result["published"]["date-parts"][0][0]
+                if "published" in result
+                else None
+            )
 
-            if year_published != date.today().year:
+            if year_published and year_published != date.today().year:
                 has_preservation = False
                 archive_count = 0
 
@@ -214,7 +218,13 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
                         f"{result['DOI']} is excluded as it is not a journal "
                         f"article"
                     )
-
+            elif "published" not in result:
+                overall_status["excluded-no-date"] += 1
+                if verbose:
+                    logging.info(
+                        f"{result['DOI']} is excluded as it is not a journal "
+                        f"article"
+                    )
             elif date.today().year == result["published"]["date-parts"][0][0]:
                 overall_status["excluded-current-year"] += 1
                 if verbose:
@@ -243,17 +253,18 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
     # determine the classes
     overall_status["member-grade"] = "Unclassified"
 
-    # 25% in 1 archive
-    if one_archive / overall_status["sample-count"] >= 0.25:
-        overall_status["member-grade"] = "Bronze"
+    if overall_status["sample-count"] > 0:
+        # 25% in 1 archive
+        if one_archive / overall_status["sample-count"] >= 0.25:
+            overall_status["member-grade"] = "Bronze"
 
-    # 50% in 2 archives
-    if two_archives / overall_status["sample-count"] >= 0.50:
-        overall_status["member-grade"] = "Silver"
+        # 50% in 2 archives
+        if two_archives / overall_status["sample-count"] >= 0.50:
+            overall_status["member-grade"] = "Silver"
 
-    # 75% in 3 archives
-    if three_archives / overall_status["sample-count"] >= 0.75:
-        overall_status["member-grade"] = "Gold"
+        # 75% in 3 archives
+        if three_archives / overall_status["sample-count"] >= 0.75:
+            overall_status["member-grade"] = "Gold"
 
     return overall_status
 
