@@ -1099,7 +1099,7 @@ class InternetArchivePreservation(models.Model):
         pi = preserved_item.filter(preserved_volumes=str(volume))
 
         if pi.count() > 0:
-            return pi, pi.preserved
+            return pi[0], True
 
         return None, False
 
